summaryrefslogtreecommitdiffstats
path: root/gst-libs/gst/media-info
diff options
context:
space:
mode:
authorThomas Vander Stichele <thomas@apestaart.org>2003-01-10 10:22:25 +0000
committerThomas Vander Stichele <thomas@apestaart.org>2003-01-10 10:22:25 +0000
commit424db0d3aea0ce26a35ba381b4e439f32e50c961 (patch)
treecf1e32dcea1deec9b9c8802af89b2cce9ac5b175 /gst-libs/gst/media-info
parent562e0b2526c75e98dfe790dba5fa50a0be0a95d3 (diff)
downloadgst-plugins-bad-424db0d3aea0ce26a35ba381b4e439f32e50c961.tar.gz
gst-plugins-bad-424db0d3aea0ce26a35ba381b4e439f32e50c961.tar.bz2
gst-plugins-bad-424db0d3aea0ce26a35ba381b4e439f32e50c961.zip
another batch of connect->link fixes please let me know about issues and please refrain of making them yourself, so t...
Original commit message from CVS: another batch of connect->link fixes please let me know about issues and please refrain of making them yourself, so that I don't spend double the time resolving conflicts
Diffstat (limited to 'gst-libs/gst/media-info')
-rw-r--r--gst-libs/gst/media-info/media-info.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/gst-libs/gst/media-info/media-info.c b/gst-libs/gst/media-info/media-info.c
index 624a06a0..4e8f56b3 100644
--- a/gst-libs/gst/media-info/media-info.c
+++ b/gst-libs/gst/media-info/media-info.c
@@ -454,8 +454,8 @@ gst_media_info_find_type (GstMediaInfo *info, const char *location)
gst_bin_add (GST_BIN (priv->pipeline), priv->typefind);
g_object_set (G_OBJECT (priv->source), "location", location, NULL);
- if (!gst_element_connect (priv->source, priv->typefind))
- g_warning ("Couldn't connect source and typefind\n");
+ if (!gst_element_link (priv->source, priv->typefind))
+ g_warning ("Couldn't link source and typefind\n");
g_signal_connect (G_OBJECT (priv->typefind), "have-type",
G_CALLBACK (have_type_callback), info);
if (gst_element_set_state (priv->pipeline, GST_STATE_PLAYING)
@@ -469,7 +469,7 @@ gst_media_info_find_type (GstMediaInfo *info, const char *location)
/*clear up typefind */
gst_element_set_state (priv->pipeline, GST_STATE_READY);
- gst_element_disconnect (priv->source, priv->typefind);
+ gst_element_unlink (priv->source, priv->typefind);
gst_bin_remove (GST_BIN (priv->pipeline), priv->typefind);
}
/* get properties of complete physical stream
@@ -683,7 +683,7 @@ gst_media_info_clear_decoder (GstMediaInfo *info)
/* clear up decoder */
/* FIXME: shouldn't need to set state here */
gst_element_set_state (info->priv->pipeline, GST_STATE_READY);
- gst_element_disconnect (info->priv->source, info->priv->decoder);
+ gst_element_unlink (info->priv->source, info->priv->decoder);
gst_bin_remove (GST_BIN (info->priv->pipeline), info->priv->decoder);
info->priv->decoder = NULL;
}
@@ -701,9 +701,9 @@ gst_media_info_set_decoder (GstMediaInfo *info, GstElement *decoder)
/* set up pipeline and connect signal handlers */
priv->decoder = decoder;
gst_bin_add (GST_BIN (priv->pipeline), decoder);
- if (!gst_element_connect (priv->source, decoder))
- g_warning ("Couldn't connect source and decoder\n");
- /* FIXME: we should be connecting to ALL possible src pads */
+ if (!gst_element_link (priv->source, decoder))
+ g_warning ("Couldn't link source and decoder\n");
+ /* FIXME: we should be link to ALL possible src pads */
if (!(priv->decoder_pad = gst_element_get_pad (decoder, "src")))
g_warning ("Couldn't get decoder pad\n");
if (!(priv->source_pad = gst_element_get_pad (priv->source, "src")))